<?php
$lang['abbr_length'] = 'L ';
$lang['abbr_width'] = 'B ';
$lang['abbr_height'] = 'H ';
$lang['add'] = 'Hinzuf&uuml;gen';
$lang['addcategory'] = 'Eine Kategorie hinzuf&uuml;gen';
$lang['addfielddef'] = 'Ein Feld hinzuf&uuml;gen';
$lang['adjustable'] = 'Anpassbar';
$lang['addproduct'] = 'Einen Artikel hinzuf&uuml;gen';
$lang['add_attrib_set'] = 'Ein Attribut hinzuf&uuml;gen';
$lang['add_category_field'] = 'Das Feld mit der Kategorie &quot;%s&quot; verkn&uuml;pfen';
$lang['add_hierarchy_item'] = 'Ein Hierarchie-Element hinzuf&uuml;gen';
$lang['add_option'] = 'Attribut-Option hinzuf&uuml;gen';
$lang['admin_only'] = 'Sollen nur Administratoren dieses Attribut sehen k&ouml;nnen?';
$lang['align_ul'] = 'Oben Links';
$lang['align_uc'] = 'Oben Mitte';
$lang['align_ur'] = 'Open Rechts';
$lang['align_ml'] = 'Mitte Links';
$lang['align_mc'] = 'Mitte Mitte';
$lang['align_mr'] = 'Mitte Rechts';
$lang['align_ll'] = 'Unten Links';
$lang['align_lc'] = 'Unten Mitte';
$lang['align_lr'] = 'Unten Rechts';
$lang['all'] = 'Alle';
$lang['allcategories'] = 'Alle Kategorien';
$lang['any'] = 'Irgend eines';
$lang['areyousure'] = 'Sind Sie sicher?';
$lang['areyousure_deleteproduct'] = 'Wollen Sie wirklich diesen Artikel und alle damit verkn&uuml;pften Informationen l&ouml;schen?';
$lang['ascending'] = 'Aufsteigend';
$lang['attribute_name'] = 'Attributname';
$lang['automatic'] = 'Automatisch';
$lang['byhierarchytemplates'] = 'Hierarchie-Report-Templates';
$lang['byhierarchytemplate_addedit'] = 'Ein Hierarchie-Report-Template hinzuf&uuml;gen/&auml;ndern';
$lang['cancel'] = 'Abbrechen';
$lang['categories'] = 'Kategorien';
$lang['category'] = 'Kategorie';
$lang['categoryexists'] = 'Eine Kategorie mit diesem Namen existiert bereits';
$lang['categorylisttemplates'] = 'Kategorielisten-Templates';
$lang['categorylisttemplate_addedit'] = ' Ein Kategorie-Listentemplate hinzuf&uuml;gen/&auml;ndern';
$lang['centimeters'] = 'Zentimeter';
$lang['checkbox'] = 'Kontrollk&auml;stchen';
$lang['confirm_copyattributes'] = 'Aany existing attribute sets for this product will be removed. Are you sure you want to continue?';
$lang['confirm_delete_hierarchy_node'] = 'M&ouml;chten Sie diesen Knoten wirklich l&ouml;schen? Alle Artikel, die diesen Knoten nutzen, werden auf &quot;no hierarchy&quot; gesetzt';
$lang['confirm_import'] = 'Wollen Sie dies WIRKLICH?\n\nFalsche Einstellungen oder eine ung&uuml;ltige Konfigurationsdatei k&ouml;nnen ein bislang funktionierendes System komplett zerst&ouml;ren.';
$lang['copy'] = 'Kopieren';
$lang['copy_attrib_sets'] = 'Atribut S&auml;tze kopieren';
$lang['copy_category'] = 'Kategorie kopieren';
$lang['createddate'] = 'Erstellungsdatum';
$lang['current_value'] = 'Aktueller Wert';
$lang['data'] = 'Daten';
$lang['default'] = 'Standardeinstellung';
$lang['defaulttemplates'] = 'Standard-Templates';
$lang['default_template_notice'] = '<strong>Achtung:</strong> Die Inhalte dieser Textfelder werden genutzt, um die voreingestellten Inhalte der Templates festzulegen, wenn &quot;Template hinzuf&uuml;gen&quot; in der jeweiligen Template-Registerkarte geklickt wird. Die Ver&auml;nderung eines Feldes hat keinen direkten Effekt auf die Webseite.';
$lang['delete'] = 'L&ouml;schen';
$lang['delete_attribset'] = 'Attribut l&ouml;schen';
$lang['delete_hierarchy_item'] = 'Hierarchie-Element l&ouml;schen';
$lang['descending'] = 'Absteigend';
$lang['description'] = 'Beschreibung';
$lang['destination'] = 'Bestimmungsort';
$lang['details'] = 'Details ';
$lang['detailtemplates'] = 'Detail-Templates';
$lang['detailtemplate_addedit'] = 'Ein Detail-Template hinzuf&uuml;gen/&auml;ndern';
$lang['dimensions'] = 'Dimensionen';
$lang['disabled'] = 'Deaktiviert';
$lang['down'] = 'Nach unten';
$lang['draft'] = 'Entwurf';
$lang['dropdown'] = 'Listenfeld';
$lang['dropdown_options'] = 'Listenfeld-Optionen <em>(nur in Listenfeld-Men&uuml;s einsetzbar)</em><br/><br/><em>(ein Eintrag pro Zeile)</em>';
$lang['edit'] = '&Auml;ndern ';
$lang['edit_attribset'] = 'Attribute bearbeiten';
$lang['edit_attribsets'] = 'Attributeinstellungen bearbeiten';
$lang['edit_attribsets_for'] = 'Attributeinstellungen bearbeiten f&uuml;r';
$lang['edit_attributes'] = 'Attribute bearbeiten';
$lang['edit_category'] = 'Kategorie bearbeiten';
$lang['edit_category_fields'] = 'Kategorienfelder bearbeiten';
$lang['edit_hierarchy_item'] = 'Hierarchie-Element bearbeiten';
$lang['error_attribset_exists'] = 'Ein Attribut mit diesem Namen existiert bereits.';
$lang['error_duplicate_sku'] = 'Doppelte Artikelnummer gefunden';
$lang['error_fieldvalue_empty'] = 'Der Wert des Feldes darf nicht leer sein';
$lang['error_fileformat'] = 'Problem mit dem Datei-Format';
$lang['error_filenotfound'] = 'Die Datei wurde nicht gefunden';
$lang['error_fileopen'] = 'Problem beim &Ouml;ffnen der Datei %s';
$lang['error_invalidparent'] = 'Ung&uuml;ltiges, &uuml;bergeordnetes Element (ein Hierarchieelement kann nicht sein eigenes &uuml;bergeordnetes Element sein)';
$lang['error_invalid_name'] = 'Der eingegebene Wert im benutzerdefinierten Formular-Feld ist ung&uuml;ltig (beinhaltet nicht-alphanumerischen Zeichen)';
$lang['error_invalid_value'] = 'Ung&uuml;ltiger Wert angegeben';
$lang['error_missingparam'] = 'Ein ben&ouml;tigter Parameter fehlt oder ist ung&uuml;ltig';
$lang['error_nameused'] = 'An Element mit diesem Namen existiert bereits';
$lang['error_nofieldtype'] = 'Bitte w&auml;hlen Sie einen Feldtyp';
$lang['error_noname'] = 'Sie m&uuml;ssen einen Namen angeben';
$lang['error_onesubscriptionfield'] = 'Es kann nur ein Abonnement-Feld angelegt werden';
$lang['error_permissiondenied'] = 'Berechtigung verweigert';
$lang['error_product_aliasused'] = 'Der eingegebene Alias wird bereits verwendet';
$lang['error_product_nameused'] = 'Ein Artikel mit diesem Namen existiert bereits';
$lang['error_product_notfound'] = 'Das angefragte Produkt konnte nicht gefunden werden';
$lang['error_product_skuused'] = 'Diese Artikelnummer wird bereits von einem anderen Artikel verwendet';
$lang['error_price_adjustment'] = 'Ung&uuml;ltige Preis-Angaben f&uuml;r das Element %s';
$lang['error_sku_required'] = 'Bitte eine eindeutige Artikelnummer eingeben';
$lang['error_upload_failed'] = 'Das Hochladen ist fehlgeschlagen: %s';
$lang['exclude_categories'] = 'Produkte aus den gew&auml;hlten Kategorieen nicht im Ergebnis anzeigen';
$lang['expire_six_months'] = 'Nach sechs Monaten';
$lang['expire_one_year'] = 'Nach einem Jahr';
$lang['expire_two_year'] = 'Nach zwei Jahren';
$lang['extra1'] = 'Extrafeld 1';
$lang['extra2'] = 'Extrafeld 2';
$lang['field'] = 'Feld';
$lang['fielddef'] = 'Felddefinition';
$lang['fielddefs'] = 'Felddefinitionen';
$lang['file'] = 'Datei';
$lang['filters'] = 'Filter';
$lang['firstpage'] = '<<';
$lang['general_settings'] = 'Allgemeine Einstellungen';
$lang['go'] = 'Los';
$lang['help'] = '<h3>Was macht dieses Modul?</h3>
<p>Dieses Modul bietet die M&ouml;glichkeit, Informationen &uuml;ber Produkte und deren Kategorien zu sammeln, organisieren und anzuzeigen. Dieses Modul kann allein eingesetzt werden oder als Teil einer E-Commerce L&ouml;sung. Das Modul unterst&uuml;tzt Produkte in mehreren Kategorien, Angaben zu Preis, Gewicht, etc. und individuelle Felder f&uuml;r jedes Produkt. Individuellen Produkt-Felder k&ouml;nnen eigene Preise zugeordnet werden. Die Umsatzsteuer kann global oder f&uuml;r jedes Produkt individuell aktiviert werden.</p>
<p>Dieses Modul unterst&uuml;tzt mehrere Bilder je Produkt, individuelle Felder verschiedener Typen und auch interne (nicht &ouml;ffentliche) Felder.</p>
<h3>Funktionen:</h3>
<ul>
  <li>Verschiedene Ansichten</li>
    <ul>
      <li>Produkt-Listenansicht</li>
      <li>Kategorie-Listenansicht</li>
      <li>Detail Ansicht</li> 
      <li>Verzweigte Hierarchie Ansichten</li>
    </ul>
  <li>Komplett Datenbank-basierende Templates</li>
  <p>Es k&ouml;nnen mehrere Templates f&uuml;r jede Ansicht gespeichert, f&uuml;r jede Ansicht ein Standard-Template festgelegt und das gew&uuml;nschte Template f&uuml;r eine Ansicht kann als Parameter im Platzhalter angegeben werden.</p>
  <li>Sortierung und Bl&auml;tter-Funktion in der Listenansicht</li>
  <li>Artikel k&ouml;nnen mehreren Kategorien zugeordnet werden</li>
  <li>Mehrere individuelle Felder k&ouml;nnen definiert werden, dabei gibt es verschiedene Typen, inklusive Bilder</li>
  <li>Automatische Thumbnail-Erzeugung</li>
  <li>Interne Felder</li>
  <li>Individuelle Produkt-Eigenschaften (mit eigenen Preisen)</li>
  <li>Felder f&uuml;r Gewicht, Umsatzsteuer und anderes (f&uuml;r die Verwendung in E-Commerce L&ouml;sungen)</li>
  <li>Artikel k&ouml;nnen den Status &quot;Ver&ouml;ffentlicht&quot; oder &quot;Entwurf&quot; haben.</li>
  <li>Unterst&uuml;tzung von Pretty URLs</li>
  <li><strong>Vieles mehr...</strong></li>
</ul>

<h3>Wie kann dieses Modul verwendet werden:</h3>
<ul>
<li>Einstellungen</li>
<p>Dies ist normalerweise nur eine Formalit&auml;t. Hier werden das Preis-Symbol und -W&auml;hrung, die anzuzeigenden Felder u.v.m. eingestellt.</p>
<li>Setup f&uuml;r Benutzer und Berechtigungen</li>
<p>Dieses Modul nutzt die &#039;Modify Templates&#039; Berechtigung, um Nutzern das Bearbeiten der Templates zu erm&ouml;glichen. Ebenso wird die &#039;Modify Site Preferences&#039; Berechtigung verwendet f&uuml;r den Einstellungs-Reiter. Um Feld Definitionen, Artikel, Kategorien oder Hierarchien zu bearbeiten, ben&ouml;tigt der Benutzer die Berechtigung &#039;Modify Products&#039;.</p>
<li>(optional) Erstellen von ein oder mehreren Kategorien</li>
<p>Dieser Schritt ist optional, aber es ist sicher ratsam, dies so fr&uuml;h wie m&ouml;glich zu tun, um sp&auml;teren Mehraufwand zu vermeiden. Um eine Kategorie hinzuzuf&uuml;gen, klicken Sie auf den Reiter &quot;Kategorien&quot; und dort auf den Link &quot;Kategorie hinzuf&uuml;gen&quot;, wo schlie&szlig;lich der Name der Kategorie angegeben werden kann.</p>
<li>(optional) Erstellen von ein oder mehreren individuellen Feldern</li>
<p>Dieser Schritt ist optional. Individuelle Felder werden nocht ben&ouml;tigt, wenn dieses Modul das gew&uuml;nschte bietet. Wenn Sie jedoch zus&auml;tzliche Informationen zum Artikel ben&ouml;tigen, k&ouml;nnen Sie hier individuelle Felder erstellen. Ein individuelles Feld zu erstellen ist &auml;hnlich wie eine Kategorie zu erstellen, abgesehen davon, dass mehr Daten angegeben werden m&uuml;ssen.</p>
<p>Derzeit sind sechs Typen von individuellen Feldern verf&uuml;gbar: &#039;textbox&#039;, &#039;checkbox&#039;, &#039;textarea&#039;, &#039;dropdown&#039; und &#039;file&#039;. W&auml;hlen Sie einen Typ aus, geben Sie dem Feld einen Namen und legen Sie fest, ob das Feld &ouml;ffentlich sein soll oder intern. Best&auml;tigen Sie schlie&szlig;lich mit &quot;Absenden&quot;.</p>
<li>Erstellen von ein oder mehreren Artikeln</li>
<p>Sie sollten ein oder mehrere Artikel erstellen, die auf der Webseite angezeigt werden sollen. Geben Sie jedem Artikel einen Namen, einen Preis und weitere Informationen.</p>
<p>Wenn Kategorien erstellt wurden, wird f&uuml;r jede Kategorie eine Checkbox angezeigt. W&auml;hlen Sie, unter welchen Kategorien der Artikel angezeigt werden soll.</p>
<p>Wenn individuelle Felder erstellt wurden, werden diese auch abgefragt. Geben Sie auch hier die vorhandenen Daten ein. Dies ist optional.</p>
<li>Einf&uuml;gen der entsprechenden Tags in das Seiten Template oder den Seiten Inhalt</li>
<p>Die einfachste Variante ist es, den <strong>{Products}</strong> Tag in den Inhalts-Textbereich oder in einem Template einzuf&uuml;gen.</p>
<p>Wenn Sie das Verhalten dieses Moduls nach Ihren W&uuml;nschen anpassen wollen, k&ouml;nnen Sie verschiedene Parameter zum <strong>{Products}</strong> Tag hinzuf&uuml;gen. Die komplette Liste der Parameter finden Sie weiter unten im Text. Wenn Sie zum Beispiel eine Liste von Produkten einer Kategorie anzeigen wollen, k&ouml;nnen Sie den Tag wie folgt verwenden: <code>{Products category=&#039;categoryname&#039;}</code></p>
</ul>
<h3>Smarty Plugins</h3>
<p>Dieses Modul erweitert Smarty um ein oder mehrere Plugins, die das Einf&uuml;gen von Artikeldaten in die Templates vereinfachen:</p>
<ul>
  <li><code>{products_getcategory categoryid=&#039;99&#039; [assign=&#039;tmp&#039;]}</code>
  <p>Das Plugin liefert die kompletten Daten zu einer Kategorie-ID und weisst diese der ggf. angegebenen Smarty Variablen zu.  Der R&uuml;ckgabewert ist ein Objekt mit allen Daten einer Kategorie, inklusive der Feldwerte.<br/>Bsp.: <code>{products_getcategory categoryid=1 assign=&#039;tmp&#039;}Category name = {$tmp->name}</code></p>
  </li>
</ul>

<h3>Support</h3>
<p>Dieses Modul beinhaltet keinen kommerziellen Support. Es existieren jedoch eine Reihe von Ressourcen, die Ihnen bei diesem Modul helfen k&ouml;nnen:</p>
<ul>
<li>F&uuml;r die neueste Version dieses Moduls, f&uuml;r FAQs oder Fehlerberichte, besuchen Sie die Entwickler-Webseite von CMS made simple: <a href="http://dev.cmsmadesimple.org">Developers Forge</a> und suchen Sie nach &#039;Products&#039;.</li>
<li>Um kommerziellen Support zu erhalten, senden Sie eine EMail zum Author <a href="mailto:calguy1000@cmsmadesimple.org">Robert Campbell</a>.</li>
<li>Zus&auml;tzliche Diskussionen &uuml;ber dieses Modul finden Sie im CMS made simple Forum: <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forum</a>.</li>
<li>F&uuml;r Fragen oder beschr&auml;nkten technischen Support kann der Author via IRC erreicht werden: <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
</ul>
<h3>Urheberrecht und Lizenz:</h3>
<p>Copyright &amp;copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org">&amp;lt;calguy1000@cmsmadesimple.org&amp;gt;</a>. Alle Rechte vorbehalten.</p>
<p>Dieses Programm ist freie Software. Sie k&ouml;nnen es unter den Bedingungen der GNU General Public License, wie von der Free Software Foundation ver&ouml;ffentlicht, weitergeben und/oder modifizieren, entweder gem&auml;&szlig; Version 2 der Lizenz oder (nach Ihrer Option) jeder sp&auml;teren Version.</p>
<p>Doch da diese Software ein Zusatzmodul zu CMS Made Simple ist gilt eine besondere Ausnahme zur GPL. 
Sie d&uuml;rfen diese Software in keiner Version von CMS Made Simple einsetzen die nicht unter der GPL lizensiert ist, oder im Administrationsbereich nicht klar und deutlich darauf hinweist, das die Site mit CMS Made Simple erstellt wurde.</p>
<p>Die Ver&ouml;ffentlichung dieses Programms erfolgt in der Hoffnung, da&szlig; es Ihnen von Nutzen sein wird, aber OHNE IRGENDEINE GARANTIE, sogar ohne die implizite Garantie der MARKTREIFE oder der VERWENDBARKEIT F&Uuml;R EINEN BESTIMMTEN ZWECK. Details finden Sie in der GNU General Public License.</p>
<p>Sie sollten ein Exemplar der GNU General Public License zusammen mit diesem Programm erhalten haben. Falls nicht, schreiben Sie an die Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA oder lesen Sie sie <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
$lang['hierarchy'] = 'Hierarchie';
$lang['hierarchy_position'] = 'Hierarchie-Position';
$lang['hierarchy_settings'] = 'Hierarchie-Einstellungen';
$lang['id'] = 'ID';
$lang['imagetext'] = 'Bild';
$lang['image_handling_settings'] = 'Einstellungen f&uuml;r die Bilderverwaltung';
$lang['import_from_csv'] = 'Produkte aus einer CSV-Datei importieren';
$lang['inches'] = 'Zoll';
$lang['include_children'] = 'Einschlie&szlig;lich Unterpunkte?';
$lang['info_alnumonly'] = 'Nur alphanumerische Zeichen. Keine Leerzeichen, Zitate oder Buchstaben/Nummern-Kombinationen';
$lang['info_attribtemplate'] = 'M&ouml;gliche Variablen sind: {$attrib_text},{$attrib_adjust},{$currency_symbol}';
$lang['info_attributes_copied'] = 'Atribute kopiert';
$lang['info_autowatermark'] = 'Es werden die Wasserzeichen-Einstellungen des CGExtensions-Moduls verwendet';
$lang['info_batchsize'] = 'Geben Sie die Anzahl der Zeilen an, die pro &quot;Block&quot; verarbeitet werden sollen. Nachdem ein Block abgearbeitet ist, wird der Import weitergeleitet und verarbeitet den n&auml;chsten Block.  Wenn bei Ihnen Speicherfehler oder Zeit&uuml;berschreitungen aufgrund der Gr&ouml;&szlig;e der verarbeiteten Datenmenge auftreten, wenden Sie sich an Ihren Hosting-Provider oder verkleinern Sie die Zeilenanzahl';
$lang['info_cart_module_params'] = 'Diese Parameter werden verwendet, um ein Warenkorb-Modul f&uuml;r die Artikel-Detail- und -Listenansicht auszuw&auml;hlen.';
$lang['info_copy_attribsets'] = 'Hiermit kopieren Sie den Attributsatz (ohne Artikelnummer) eines anderen Artikels.';
$lang['info_createfields'] = 'Unbekannte Artikelfelder automatisch erstellen? <em>(werden als Textfelder erstellt)</em>';
$lang['info_createcategories'] = 'In der CSV-Datei angegebene, aber bisher fehlende Artikelkategorien automatisch erzeugen';
$lang['info_createhierarchy'] = 'In der CSV-Datei angegebene, aber bisher fehlende Artikelhierarchien automatisch erzeugen';
$lang['info_decimal_units'] = 'Dieses System versteht (.) als Dezimalstellen-Trennzeichen, z.B.: <strong>5.25</strong>';
$lang['info_delimiter'] = 'Legen Sie hier das (oder die) Zeichen fest, die die Felder voneinander trennen';
$lang['info_duplicateproducts'] = 'Legen Sie fest wie Artikel behandelt werden, deren Name schon in der CSV Datei vorhanden ist';
$lang['info_fielddefs_tab'] = '<strong>Achtung: </strong> Alle Felder, die hier definiert werden, sind f&uuml;r alle Artikel verf&uuml;gbar.';
$lang['info_fieldproblems'] = 'Bei einem oder mehreren benutzerdefinierten Feldern wurden Probleme festgestellt. Die Aktion wurde erfolgreich abgeschlossen, Sie sollten jedoch die Ursache der Probleme herausfinden.';
$lang['info_handleimages'] = 'Sollen beim Import in einer Spalte gefundene Bilddateien von der Quellposition verschoben, mit Wasserzeichen versehen und ein Vorschaubild erstellt und der Feldtyp auf &quot;Bild&quot; gesetzt werden';
$lang['info_hierpage'] = 'Diese Seite f&uuml;r Hierarchieansichten verwenden.  Die Seiten-ID wird in der URL nicht verwendet.';
$lang['info_imagepath'] = 'Ein Pfad (relativ zum Uploads Verzeichnis) in dem die in der Importdatei angegebenen Bilder liegen';
$lang['info_import_test_passed'] = 'Die angegebene Eingabedatei wurde einem Kurztest unterzogen und alles scheint in Ordnung zu sein.<br/>Dies ist kein Indiz daf&uuml;r, das die Datei fehlerfrei ist.';
$lang['info_prettyhierurls'] = 'Den Hierarchienamen in die URL einf&uuml;gen';
$lang['info_price_adjustment'] = 'G&uuml;ltige Eingaben sind +-*#.##';
$lang['info_prodnotfound'] = 'Wie wird ein direkter Aufruf einer Artikeldetailseite per URL behandelt, wenn der Artikel - aus welchen Gr&uuml;nden auch immer (deaktiviert, gel&ouml;scht, usw) - nicht verf&uuml;gbar ist.';
$lang['info_publicfield'] = '&Ouml;ffentliche Felder sind auf der Webseite f&uuml;r jeden sichtbar.';
$lang['label'] = 'Beschriftung';
$lang['label_skip'] = '&Uuml;berspringen';
$lang['label_overwrite'] = '&Uuml;berschreiben';
$lang['lastpage'] = '>>';
$lang['last_modified'] = 'Letzte &Auml;nderung';
$lang['logotext'] = 'Zweites Bild';
$lang['maxlength'] = 'Maximale L&auml;nge <em>(nur auf Text-Felder anwendbar)</em>';
$lang['modifieddate'] = '&Auml;nderungs-Datum';
$lang['module_description'] = 'Ein Modul, um einen Katalog von Artikeln, deren Preise, Bilder, etc. zu verwalten und Benutzern zu erlauben, diese an einen Warenkorb zu &uuml;bergeben.';
$lang['move_down'] = 'Nach unten';
$lang['move_up'] = 'Nach oben';
$lang['name'] = 'Name ';
$lang['needpermission'] = 'Sie haben nicht die erforderliche Berechtigung: %s';
$lang['new_category_name'] = 'Neuer Kategorien-Name';
$lang['nextpage'] = '>';
$lang['no'] = 'Nein';
$lang['nonamegiven'] = 'Es wurde kein Name angegeben';
$lang['none'] = 'Keines';
$lang['nothing_selectd'] = 'Nichts ausgew&auml;hlt';
$lang['of'] = 'Von';
$lang['operation_complete'] = 'Vorgang abgeschlossen';
$lang['page'] = 'Seite';
$lang['page_of'] = 'Seite %s von %s';
$lang['page_limit'] = 'Seiten-Anzahl';
$lang['param_action'] = 'Legen Sie das Verhalten des Moduls fest. M&ouml;gliche Werte sind:
<ul>
  <li>hierarchy -- zeigt eine Artikel-Liste nach der Hierarchie an</li>
  <li>categorylist - zeigt eine Liste der Produktkategorien an</li>
  <li><em>default</em> - zeigt eine Zusammenfassung der Produkte an</li>
  <li>details - zeigt die Detailansicht eines einzelnen Artikels an</li>
</ul>';
$lang['param_category'] = 'Wenn dieser Parameter in der <em>default</em> Listenansicht verwendet wird, werden nur Artikel zur angegebenen Kategorie angezeigt. Mehrere Kategorien k&ouml;nnen durch Kommas getrennt angegeben werden. Der Parameter-Name sollte nicht &uuml;bereinstimmen mit dem Namen einer existierenden Kategorie.';
$lang['param_categoryfield'] = 'Dieser Parameter ist nur in der Kategorie-Ausgabe sinnvoll. Mit ihm k&ouml;nnen Kategorien anhand eines Kategoriefeldes gefiltert werden.  Die Filterung funktioniert nicht wenn gleichzeitig ein &quot;category&quot; oder &quot;category_id&quot; Parameter angegeben wird.  Geben Sie eine kommagetrennte Liste von Kategoriefeldnamen und -werten an.  Bsp.:  categorylist=&quot;Feldname:Wert,Weiterer Feldname:Wert&quot;';
$lang['param_categorylisttemplate'] = 'Dieser Parameter ist nur in der Kategorie-Ausgabe sinnvoll. Er wird benutzt, um das Template anzugeben, welches verwendet werden soll. Wenn kein Wert angegeben ist, wird das Default-Template verwendet.';
$lang['param_categorylistdtltemplate'] = 'Dieser Parameter ist nur in der Kategorie-Ausgabe sinnvoll.  Er gibt das Kategorielisten-Template an, das f&uuml;r die Anzeige von Kategoriedetails verwendet werden soll.  Wenn kein Wert angegeben ist, wird das Standard-Template verwendet.';
$lang['param_detailpage'] = 'Dies legt die Seiten-ID (pageid) oder den Alias (alias) fest, welche(r) benutzt werden soll, um die Detailansicht auszugeben.';
$lang['param_detailtemplate'] = 'Dieser Parameter wird verwendet, um das Template festzulegen, welches f&uuml;r die Artikel-Detailansicht verwendet werden soll. Ohne Vorgabe wird das Standard-Template verwendet.';
$lang['param_excludecat'] = 'Applicable only to the default (summary) view, this parameter will allow excluding products that are in a specific category from the result. A comma separated list of category names is allowed. This parameter can work in conjunction with the category parameter to provide a list of the products that are in this category, but not in that category';
$lang['param_field'] = 'Used only in the <em>fieldlist</em> action, this parameter is required to specify the name of a user defined property to create a list from.';
$lang['param_fieldval'] = 'Used only in the <em>default</em> action, this parameter allows specifying a field value to limit results by.  Special values for this field are &quot;::null::&quot; &quot;::notnull::&quot;';
$lang['param_hierarchy'] = 'Dieser Parameter ist nur in der <em>default</em>-Ansicht sinnvoll. Er wird verwendet, um nur Artikel anzuzeigen, die einer bestimmten Hierarchie angeh&ouml;ren. Dabei k&ouml;nnen Wildcards verwendet werden, um &uuml;bergeordnete/untergeordnete Beziehungen ebenfalls anzuzeigen. Z.B. gibt {Products hierarchy=&#039;LKWs*&#039;} eine Zusammenfassung aller LKWs aus, einschlie&szlig;lich aller untergeordneten Elemente der Hierarchie. Genauso gibt {Products hierarchy=&#039;*LKWs&#039;} eine Zusammenfassung aller LKWs aus, einschlie&szlig;lich der &uuml;bergeordneten Elemente in der Hierarchie.';
$lang['param_hierarchytemplate'] = 'Dieser Parameter wird verwendet, um das Template festzulegen, welches f&uuml;r die Hierarchieansicht verwendet werden soll. Ohne Vorgabe wird das Standard-Template verwendet.';
$lang['param_inline'] = 'Useful only with the search action, this parameter specifies that the output of the summary view should be displayed inline';
$lang['param_pagelimit'] = 'Dieser Parameter ist nur in der <em>default</em>-Ausgabe sinnvoll. Er legt fest, wie viele Elemente pro Seite angezeigt werden sollen.';
$lang['param_parent'] = 'Dieser Parameter ist nur in der <em>hierarchy</em>-Ausgabe sinnvoll. Er legt die Hierarchie-ID fest, ab welcher die Artikel ausgegeben werden sollen.';
$lang['param_productid'] = 'Dieser Parameter ist nur in der <em>detail</em> Artikelansicht sinnvoll. Er legt fest, welcher Artikel angezeigt werden soll.';
$lang['param_productlist'] = 'Applicable only to the default (summary) view, this parameter allows specifying a comma separated list of integer product ids to display.  No pagination or sorting is performed on these values, and if specified the other filtering parameters to the summary view are ignored.';
$lang['param_resultpage'] = 'Applicable only to the search, and category list actions, this parameter specifies a page id or alias to use to display the summary results';
$lang['param_searchfield'] = 'Applicable only to the search action, this parameter may contain a comma separated list of field names to include in the search';
$lang['param_searchformtemplate'] = 'Applicable only to the search action, thisparameter allows specifying a non default search form template';
$lang['param_showall'] = 'Dieser Parameter ist nur in der <em>categorylist</em> Kategorielistenansicht sinnvoll. Ist dieser Wert gr&ouml;&szlig;er als 0, werden alle Kategien angezeigt (au&szlig;er denen, die noch keine Artikel enthalten).';
$lang['param_sortorder'] = 'Legt die Reihenfolge der Feld-Sortierung in der Listenansicht fest. M&ouml;gliche Werte sind:
<ul>
  <li><strong>asc</strong> -- Aufsteigende Reihenfolge</li>
  <li>desc -- Absteigende Reihenfolge</li>
</ul>';
$lang['param_sortby'] = 'Dieser Parameter ist nur in der Listenansicht sinnvoll. Er legt die Sortierung der Artikel fest. M&ouml;gliche Werte sind:
<ul>
  <li><strong>product_name</strong> -- der Artikelname</li>
  <li>id -- die Artikel-ID</li>
  <li>weight -- das Gewicht des Artikels</li>
  <li>price -- der Preis des Artikels</li>
  <li>status -- Status (Entwurf oder Ver&ouml;ffentlicht)</li>
  <li>random -- verwendet bei jeder Anfrage eine zuf&auml;llige Reihenfolge</li>
  <li>created -- das Erstellungsdatum des Artikels/li>
  <li>modified -- das &Auml;nderungsdatum des Artikels</li>
</ul>';
$lang['param_sorttype'] = 'Applicable only to the default summary view, this parameter is used to convert the values to another type for sorting.  valid values are STRING,SIGNED and UNSIGNED.  If not supplied the default STRING type is assumed.';
$lang['param_summarypage'] = 'Applicable only to the action=hierarchy, allows specifying a page id or alias that will be used for any links to summary view';
$lang['param_summarytemplate'] = 'Dieser Parameter wird verwendet, um das Template festzulegen, welches f&uuml;r die Zusammenfassungsansicht verwendet werden soll. Ohne Vorgabe wird das Standard-Template verwendet.';
$lang['parent'] = '&Uuml;bergeordnetes Element';
$lang['postinstall'] = 'Das Products-Modul wurde  installiert.';
$lang['postuninstall'] = 'Das Products-Modul wurde einschlie&szlig;lich aller zugeh&ouml;rigen Daten entfernt.';
$lang['preferences'] = 'Einstellungen';
$lang['preuninstall'] = 'Wenn Sie dieses Modul entfernen, werden auch alle zugeh&ouml;rigen Daten gel&ouml;scht. Wollen Sie das wirklich?';
$lang['price'] = 'Preis';
$lang['price_adjustment'] = 'Preis-Einstellung';
$lang['prevpage'] = '<';
$lang['product'] = 'Artikel';
$lang['productname'] = 'Artikel-Name';
$lang['products'] = 'Artikel';
$lang['product_detail_settings'] = 'Artikeldetail-Einstellungen';
$lang['product_editing_settings'] = 'Produkt Bearbeitungsoptionen ';
$lang['product_summary_settings'] = 'Produkt&uuml;bersicht Einstellungen';
$lang['product_hierarchy'] = 'Artikel-Hierarchie';
$lang['product_manager'] = 'Artikelverwaltung';
$lang['progress'] = 'Fortschritt';
$lang['prompt'] = 'Eingabe';
$lang['prompt_add_attribset'] = 'Attributeinstellungen hinzuf&uuml;gen/bearbeiten';
$lang['prompt_allowed_filetypes'] = 'Das Hochladen von Dateien mit diesen Endungen (f&uuml;r Felder des Typs &#039;file&#039;) erlauben';
$lang['prompt_allowed_imagetypes'] = 'Das Hochladen von Bildern mit diesen Endungen (f&uuml;r Felder des Typs &#039;image&#039;) erlauben';
$lang['prompt_attribtemplate'] = 'Template f&uuml;r die Anzeige von Produkt Attributwerte in Dropdown';
$lang['prompt_autothumbnail'] = 'Vorschaubilder automatisch erzeugen';
$lang['prompt_autothumbnail_size'] = 'Maximale Gr&ouml;&szlig;e der Vorschaubilder.';
$lang['prompt_autopreviewimg'] = 'Automatisch Vorschaubilder der Bilder erstellen';
$lang['prompt_autopreviewimg_size'] = 'Maximale Gr&ouml;&szlig;e (gr&ouml;&szlig;te Ausdehnung) des Vorschaubildes.';
$lang['prompt_autowatermark'] = 'Automatisch Wasserzeichen auf den Bildern erzeugen';
$lang['prompt_applicable'] = 'Aktivierung per Voreinstellung f&uuml;r alle neuen Artikel';
$lang['prompt_batchsize'] = 'Blockgr&ouml;&szlig;e';
$lang['prompt_cart_module'] = 'Cart-Modul';
$lang['prompt_cart_module_params'] = 'Cart-Modul Parameter';
$lang['prompt_createcategories'] = 'Kategorien erstellen';
$lang['prompt_createfields'] = 'Artikelfelder erstellen?';
$lang['prompt_createhierarchy'] = 'Eine Artikel-Hierarchie erstellen';
$lang['prompt_csvfile'] = 'Eine CSV-Datei hochladen';
$lang['prompt_currencycode'] = 'W&auml;hrungs-Zeichen';
$lang['prompt_currencysymbol'] = 'W&auml;hrungssymbol';
$lang['prompt_default_status'] = 'Voreingestellt haben alle neuen Artikel diesen Status';
$lang['prompt_default_taxable'] = 'Voreingestellt enthalten alle neuen Artikel einen Steueranteil';
$lang['prompt_deleteproductfiles'] = 'Alle zum Artikel geh&ouml;renden Dateien l&ouml;schen, wenn der Artikel gel&ouml;scht wird?';
$lang['prompt_delimiter'] = 'Feldtrenner';
$lang['prompt_detailpage'] = 'Voreingestellte Detail-Seite';
$lang['prompt_detailsfor'] = 'Details f&uuml;r %s';
$lang['prompt_duplicateproducts'] = 'Wie sollen doppelte Produkte gehandhabt werden?';
$lang['prompt_false'] = 'Nein';
$lang['prompt_handleimages'] = 'Bilder verarbeiten?';
$lang['prompt_imagepath'] = 'Bilderpfad';
$lang['prompt_lengthunits'] = 'L&auml;ngeneinheiten';
$lang['prompt_notfound_behavior'] = 'Welche Aktion soll ausgef&uuml;hrt werden, wenn ein Artikel nicht angezeigt werden konnte?';
$lang['prompt_notfound_404'] = 'Einen 404er Fehler erzeugen';
$lang['prompt_notfound_301'] = 'Eine 301er Weiterleitung erzeugen';
$lang['prompt_notfound_errormsg'] = 'Eine Fehlermeldung anzeigen';
$lang['prompt_notfound_msg'] = 'Fehlermeldung, wenn ein Artikel nicht gefunden werden konnte';
$lang['prompt_notfound_page'] = 'Seite f&uuml;r dauerhafte Umleitung?';
$lang['prompt_hierpage'] = 'Voreingestellte Seite f&uuml;r Hierarchie-Listenansicht';
$lang['prompt_prettyhierurls'] = 'Suchmaschinenfreundliche URLs (Pretty URLS) f&uuml;r Hierarchieansichten verwenden';
$lang['prompt_prod_detailpage'] = 'Standardseite f&uuml;r Produkt Detailansicht';
$lang['prompt_products_matching'] = 'Produkte passend %s';
$lang['prompt_sku_required'] = 'Art.-Nr ist ein Pflichtfeld (muss bei allen Artikeln angegeben werden)';
$lang['prompt_summarypagelimit'] = 'Voreingestelltes Produktlimit in der Listenansicht';
$lang['prompt_summarysortorder'] = 'Voreingestellte Sortier-Reihenfolge in der Listenansicht';
$lang['prompt_summarysorting'] = 'Voreingestelltes Sortier-Feld in der Listenansicht';
$lang['prompt_template'] = 'Template-Quelle';
$lang['prompt_true'] = 'Ja';
$lang['prompt_urlprefix'] = 'Diese Zeichenkette in alle URLs einf&uuml;gen, die sich auf dieses Modul beziehen';
$lang['prompt_use_detailpage_for_search'] = 'Diese Seite auch f&uuml;r Suchergebnisse verwenden <em>(Ersetzt den <code>resultpage</code> Parameter des Suche Moduls)</em>';
$lang['prompt_usehierpathurls'] = 'Die Hierarchienamen in die URL von Artikeldetails einf&uuml;gen';
$lang['prompt_weightunits'] = 'Gewichts-Einheit';
$lang['public'] = 'Ist dies ein &ouml;ffentliches Feld?';
$lang['published'] = 'Ver&ouml;ffentlicht';
$lang['random'] = 'Zuf&auml;llig';
$lang['resettofactory'] = 'Auf die programmseitigen Voreinstellungen zur&uuml;cksetzen';
$lang['return'] = 'Zur&uuml;ck';
$lang['return_to_top'] = 'Zur&uuml;ck nach oben';
$lang['root'] = 'Wurzelverzeichnis';
$lang['search_description'] = 'Suche nach Eigenschaft Beschreibung';
$lang['search_expr'] = 'Sollte die Abfrage f&uuml;r alle oder einen der Tests unten entsprechen?';
$lang['search_name'] = 'Suche nach Eigenschaft Name';
$lang['search_price'] = 'Preisspanne';
$lang['searchtemplate_addedit'] = 'Hinzuf&uuml;gen/Bearbeiten Suchformular Template';
$lang['searchtemplates'] = 'Suchformular Templates';
$lang['select_all'] = 'Alle ausw&auml;hlen';
$lang['select_one'] = 'Bitte ausw&auml;hlen';
$lang['setdraft'] = 'Status auf &quot;Enturf&quot; setzen';
$lang['setpublished'] = 'Status auf &quot;Ver&ouml;ffentlicht&quot; setzen';
$lang['sku'] = 'Art.-Nr.';
$lang['sort_by'] = 'Sortiert nach';
$lang['sort_order'] = 'Sortier-Reihenfolge';
$lang['source'] = 'Quelle';
$lang['status'] = 'Status ';
$lang['submit'] = 'Absenden';
$lang['subscription'] = 'Abonnement';
$lang['subscr_expiry'] = 'Verfall';
$lang['subscr_expiry2'] = 'Verf&auml;llt';
$lang['subscr_monthly'] = 'Monatlich';
$lang['subscr_delperiod'] = 'Liefer-H&auml;ufigkeit';
$lang['subscr_delperiod2'] = 'Geliefert';
$lang['subscr_payperiod'] = 'Zahlungs-H&auml;ufigkeit';
$lang['subscr_payperiod2'] = 'Bezahlt';
$lang['subscr_quarterly'] = 'Viertelj&auml;hrlich';
$lang['subscr_semianually'] = 'Halbj&auml;hrlich';
$lang['subscr_yearly'] = 'J&auml;hrlich';
$lang['summarytemplates'] = 'Zusammenfassungs-Templates';
$lang['summarytemplate_addedit'] = 'Ein Zusammenfassungs-Template hinzuf&uuml;gen/&auml;ndern';
$lang['taxable'] = 'MwSt.';
$lang['test'] = 'Test ';
$lang['textarea'] = 'Mehrzeiliges Textfeld';
$lang['textbox'] = 'Einzeiliges Textfeld';
$lang['title_byhierarchy_dflttemplate'] = 'Voreinstellung Neues Hierarchie Ausgabe Template';
$lang['title_categorylist_dflttemplate'] = 'Voreinstellung Neues Kategorie-Ausgabe Template';
$lang['title_detail_dflttemplate'] = 'Voreinstellung Neues Artikel-Detailansicht Template';
$lang['title_search_dflttemplate'] = 'Voreinstellung Neues Suchformular Template';
$lang['title_summary_dflttemplate'] = 'Voreinstellung Neues Artikel-Listenansicht Template';
$lang['type'] = 'Typ';
$lang['up'] = 'Nach oben';
$lang['update'] = 'Aktualisieren';
$lang['upload'] = 'Hochzuladende Datei ausw&auml;hlen';
$lang['url_alias'] = 'URL-Alias';
$lang['valid'] = 'G&uuml;ltig';
$lang['value'] = 'Wert';
$lang['values'] = 'Werte';
$lang['view'] = 'Anzeigen';
$lang['viewable_fields'] = 'W&auml;hlen Sie benutzerdefinierte Felder in der Tabellenansicht';
$lang['watermark_location'] = 'Platzierung des Wasserzeichens';
$lang['weight'] = 'Gewicht';
$lang['with_selected'] = 'Ausgew&auml;hlte Eintr&auml;ge';
$lang['yes'] = 'Ja';
$lang['qca'] = 'P0-1362779760-1309265682636';
$lang['utma'] = '156861353.1681295217.1311961821.1312317698.1312377783.16';
$lang['utmz'] = '156861353.1311961821.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
$lang['utmc'] = '156861353';
?>